Class: Adyen::AccountHoldersApi
- Defined in:
- lib/adyen/services/balancePlatform/account_holders_api.rb
Overview
NOTE: This class is auto generated by OpenAPI Generator Ref: openapi-generator.tech
Do not edit the class manually.
Instance Attribute Summary collapse
-
#service ⇒ Object
Returns the value of attribute service.
-
#version ⇒ Object
Returns the value of attribute version.
Instance Method Summary collapse
-
#create_account_holder(request, headers: {}) ⇒ Object
Create an account holder.
-
#get_account_holder(id, headers: {}) ⇒ Object
Get an account holder.
-
#get_all_balance_accounts_of_account_holder(id, headers: {}, query_params: {}) ⇒ Object
Get all balance accounts of an account holder.
-
#get_all_transaction_rules_for_account_holder(id, headers: {}) ⇒ Object
Get all transaction rules for an account holder.
-
#get_tax_form(id, headers: {}, query_params: {}) ⇒ Object
Get a tax form.
-
#get_tax_form_summary(id, headers: {}, query_params: {}) ⇒ Object
Get summary of tax forms for an account holder.
-
#initialize(client, version = DEFAULT_VERSION) ⇒ AccountHoldersApi
constructor
A new instance of AccountHoldersApi.
-
#update_account_holder(request, id, headers: {}) ⇒ Object
Update an account holder.
Methods inherited from Service
action_for_method_name, #create_query_string
Constructor Details
#initialize(client, version = DEFAULT_VERSION) ⇒ AccountHoldersApi
Returns a new instance of AccountHoldersApi.
11 12 13 |
# File 'lib/adyen/services/balancePlatform/account_holders_api.rb', line 11 def initialize(client, version = DEFAULT_VERSION) super(client, version, 'BalancePlatform') end |
Instance Attribute Details
#service ⇒ Object
Returns the value of attribute service.
9 10 11 |
# File 'lib/adyen/services/balancePlatform/account_holders_api.rb', line 9 def service @service end |
#version ⇒ Object
Returns the value of attribute version.
9 10 11 |
# File 'lib/adyen/services/balancePlatform/account_holders_api.rb', line 9 def version @version end |
Instance Method Details
#create_account_holder(request, headers: {}) ⇒ Object
Create an account holder
16 17 18 19 20 21 |
# File 'lib/adyen/services/balancePlatform/account_holders_api.rb', line 16 def create_account_holder(request, headers: {}) endpoint = build_endpoint('/accountHolders') action = { method: 'post', url: endpoint } @client.call_adyen_api(@service, action, request, headers, @version) end |
#get_account_holder(id, headers: {}) ⇒ Object
Get an account holder
24 25 26 27 28 29 |
# File 'lib/adyen/services/balancePlatform/account_holders_api.rb', line 24 def get_account_holder(id, headers: {}) endpoint = build_endpoint('/accountHolders/{id}', id) action = { method: 'get', url: endpoint } @client.call_adyen_api(@service, action, {}, headers, @version) end |
#get_all_balance_accounts_of_account_holder(id, headers: {}, query_params: {}) ⇒ Object
Get all balance accounts of an account holder
32 33 34 35 36 37 |
# File 'lib/adyen/services/balancePlatform/account_holders_api.rb', line 32 def get_all_balance_accounts_of_account_holder(id, headers: {}, query_params: {}) endpoint = build_endpoint('/accountHolders/{id}/balanceAccounts', id) endpoint += create_query_string(query_params) action = { method: 'get', url: endpoint } @client.call_adyen_api(@service, action, {}, headers, @version) end |
#get_all_transaction_rules_for_account_holder(id, headers: {}) ⇒ Object
Get all transaction rules for an account holder
40 41 42 43 44 45 |
# File 'lib/adyen/services/balancePlatform/account_holders_api.rb', line 40 def get_all_transaction_rules_for_account_holder(id, headers: {}) endpoint = build_endpoint('/accountHolders/{id}/transactionRules', id) action = { method: 'get', url: endpoint } @client.call_adyen_api(@service, action, {}, headers, @version) end |
#get_tax_form(id, headers: {}, query_params: {}) ⇒ Object
Get a tax form
48 49 50 51 52 53 |
# File 'lib/adyen/services/balancePlatform/account_holders_api.rb', line 48 def get_tax_form(id, headers: {}, query_params: {}) endpoint = build_endpoint('/accountHolders/{id}/taxForms', id) endpoint += create_query_string(query_params) action = { method: 'get', url: endpoint } @client.call_adyen_api(@service, action, {}, headers, @version) end |
#get_tax_form_summary(id, headers: {}, query_params: {}) ⇒ Object
Get summary of tax forms for an account holder
56 57 58 59 60 61 |
# File 'lib/adyen/services/balancePlatform/account_holders_api.rb', line 56 def get_tax_form_summary(id, headers: {}, query_params: {}) endpoint = build_endpoint('/accountHolders/{id}/taxFormSummary', id) endpoint += create_query_string(query_params) action = { method: 'get', url: endpoint } @client.call_adyen_api(@service, action, {}, headers, @version) end |
#update_account_holder(request, id, headers: {}) ⇒ Object
Update an account holder
64 65 66 67 68 69 |
# File 'lib/adyen/services/balancePlatform/account_holders_api.rb', line 64 def update_account_holder(request, id, headers: {}) endpoint = build_endpoint('/accountHolders/{id}', id) action = { method: 'patch', url: endpoint } @client.call_adyen_api(@service, action, request, headers, @version) end |