Class: Adyen::PaymentInstrumentGroupsApi
- Defined in:
- lib/adyen/services/balancePlatform/payment_instrument_groups_api.rb
Overview
NOTE: This class is auto generated by OpenAPI Generator Ref: openapi-generator.tech
Do not edit the class manually.
Instance Attribute Summary collapse
-
#service ⇒ Object
Returns the value of attribute service.
-
#version ⇒ Object
Returns the value of attribute version.
Instance Method Summary collapse
-
#create_payment_instrument_group(request, headers: {}) ⇒ Object
Create a payment instrument group.
-
#get_all_transaction_rules_for_payment_instrument_group(id, headers: {}) ⇒ Object
Get all transaction rules for a payment instrument group.
-
#get_payment_instrument_group(id, headers: {}) ⇒ Object
Get a payment instrument group.
-
#initialize(client, version = DEFAULT_VERSION) ⇒ PaymentInstrumentGroupsApi
constructor
A new instance of PaymentInstrumentGroupsApi.
Methods inherited from Service
action_for_method_name, #create_query_string
Constructor Details
#initialize(client, version = DEFAULT_VERSION) ⇒ PaymentInstrumentGroupsApi
Returns a new instance of PaymentInstrumentGroupsApi.
11 12 13 |
# File 'lib/adyen/services/balancePlatform/payment_instrument_groups_api.rb', line 11 def initialize(client, version = DEFAULT_VERSION) super(client, version, 'BalancePlatform') end |
Instance Attribute Details
#service ⇒ Object
Returns the value of attribute service.
9 10 11 |
# File 'lib/adyen/services/balancePlatform/payment_instrument_groups_api.rb', line 9 def service @service end |
#version ⇒ Object
Returns the value of attribute version.
9 10 11 |
# File 'lib/adyen/services/balancePlatform/payment_instrument_groups_api.rb', line 9 def version @version end |
Instance Method Details
#create_payment_instrument_group(request, headers: {}) ⇒ Object
Create a payment instrument group
16 17 18 19 20 21 |
# File 'lib/adyen/services/balancePlatform/payment_instrument_groups_api.rb', line 16 def create_payment_instrument_group(request, headers: {}) endpoint = build_endpoint('/paymentInstrumentGroups') action = { method: 'post', url: endpoint } @client.call_adyen_api(@service, action, request, headers, @version) end |
#get_all_transaction_rules_for_payment_instrument_group(id, headers: {}) ⇒ Object
Get all transaction rules for a payment instrument group
24 25 26 27 28 29 |
# File 'lib/adyen/services/balancePlatform/payment_instrument_groups_api.rb', line 24 def get_all_transaction_rules_for_payment_instrument_group(id, headers: {}) endpoint = build_endpoint('/paymentInstrumentGroups/{id}/transactionRules', id) action = { method: 'get', url: endpoint } @client.call_adyen_api(@service, action, {}, headers, @version) end |
#get_payment_instrument_group(id, headers: {}) ⇒ Object
Get a payment instrument group
32 33 34 35 36 37 |
# File 'lib/adyen/services/balancePlatform/payment_instrument_groups_api.rb', line 32 def get_payment_instrument_group(id, headers: {}) endpoint = build_endpoint('/paymentInstrumentGroups/{id}', id) action = { method: 'get', url: endpoint } @client.call_adyen_api(@service, action, {}, headers, @version) end |