Class: Adyen::PaymentsApi
- Defined in:
- lib/adyen/services/checkout/payments_api.rb
Overview
NOTE: This class is auto generated by OpenAPI Generator Ref: openapi-generator.tech
Do not edit the class manually.
Instance Attribute Summary collapse
-
#service ⇒ Object
Returns the value of attribute service.
-
#version ⇒ Object
Returns the value of attribute version.
Instance Method Summary collapse
-
#card_details(request, headers: {}) ⇒ Object
Get the brands and other details of a card.
-
#get_result_of_payment_session(session_id, headers: {}, query_params: {}) ⇒ Object
Get the result of a payment session.
-
#initialize(client, version = DEFAULT_VERSION) ⇒ PaymentsApi
constructor
A new instance of PaymentsApi.
-
#payment_methods(request, headers: {}) ⇒ Object
Get a list of available payment methods.
-
#payments(request, headers: {}) ⇒ Object
Start a transaction.
-
#payments_details(request, headers: {}) ⇒ Object
Submit details for a payment.
-
#sessions(request, headers: {}) ⇒ Object
Create a payment session.
Methods inherited from Service
action_for_method_name, #create_query_string
Constructor Details
#initialize(client, version = DEFAULT_VERSION) ⇒ PaymentsApi
Returns a new instance of PaymentsApi.
11 12 13 |
# File 'lib/adyen/services/checkout/payments_api.rb', line 11 def initialize(client, version = DEFAULT_VERSION) super(client, version, 'Checkout') end |
Instance Attribute Details
#service ⇒ Object
Returns the value of attribute service.
9 10 11 |
# File 'lib/adyen/services/checkout/payments_api.rb', line 9 def service @service end |
#version ⇒ Object
Returns the value of attribute version.
9 10 11 |
# File 'lib/adyen/services/checkout/payments_api.rb', line 9 def version @version end |
Instance Method Details
#card_details(request, headers: {}) ⇒ Object
Get the brands and other details of a card
16 17 18 19 20 21 |
# File 'lib/adyen/services/checkout/payments_api.rb', line 16 def card_details(request, headers: {}) endpoint = build_endpoint('/cardDetails') action = { method: 'post', url: endpoint } @client.call_adyen_api(@service, action, request, headers, @version) end |
#get_result_of_payment_session(session_id, headers: {}, query_params: {}) ⇒ Object
Get the result of a payment session
24 25 26 27 28 29 |
# File 'lib/adyen/services/checkout/payments_api.rb', line 24 def get_result_of_payment_session(session_id, headers: {}, query_params: {}) endpoint = build_endpoint('/sessions/{sessionId}', session_id) endpoint += create_query_string(query_params) action = { method: 'get', url: endpoint } @client.call_adyen_api(@service, action, {}, headers, @version) end |
#payment_methods(request, headers: {}) ⇒ Object
Get a list of available payment methods
32 33 34 35 36 37 |
# File 'lib/adyen/services/checkout/payments_api.rb', line 32 def payment_methods(request, headers: {}) endpoint = build_endpoint('/paymentMethods') action = { method: 'post', url: endpoint } @client.call_adyen_api(@service, action, request, headers, @version) end |
#payments(request, headers: {}) ⇒ Object
Start a transaction
40 41 42 43 44 45 |
# File 'lib/adyen/services/checkout/payments_api.rb', line 40 def payments(request, headers: {}) endpoint = build_endpoint('/payments') action = { method: 'post', url: endpoint } @client.call_adyen_api(@service, action, request, headers, @version) end |
#payments_details(request, headers: {}) ⇒ Object
Submit details for a payment
48 49 50 51 52 53 |
# File 'lib/adyen/services/checkout/payments_api.rb', line 48 def payments_details(request, headers: {}) endpoint = build_endpoint('/payments/details') action = { method: 'post', url: endpoint } @client.call_adyen_api(@service, action, request, headers, @version) end |
#sessions(request, headers: {}) ⇒ Object
Create a payment session
56 57 58 59 60 61 |
# File 'lib/adyen/services/checkout/payments_api.rb', line 56 def sessions(request, headers: {}) endpoint = build_endpoint('/sessions') action = { method: 'post', url: endpoint } @client.call_adyen_api(@service, action, request, headers, @version) end |