Class: Adyen::TaxEDeliveryConsentApi

Inherits:
Service
  • Object
show all
Defined in:
lib/adyen/services/legalEntityManagement/tax_e_delivery_consent_api.rb

Overview

NOTE: This class is auto generated by OpenAPI Generator Ref: openapi-generator.tech

Do not edit the class manually.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Service

action_for_method_name, #create_query_string

Constructor Details

#initialize(client, version = DEFAULT_VERSION) ⇒ TaxEDeliveryConsentApi

Returns a new instance of TaxEDeliveryConsentApi.



11
12
13
# File 'lib/adyen/services/legalEntityManagement/tax_e_delivery_consent_api.rb', line 11

def initialize(client, version = DEFAULT_VERSION)
  super(client, version, 'LegalEntityManagement')
end

Instance Attribute Details

#serviceObject

Returns the value of attribute service.



9
10
11
# File 'lib/adyen/services/legalEntityManagement/tax_e_delivery_consent_api.rb', line 9

def service
  @service
end

#versionObject

Returns the value of attribute version.



9
10
11
# File 'lib/adyen/services/legalEntityManagement/tax_e_delivery_consent_api.rb', line 9

def version
  @version
end

Instance Method Details

Check the status of consent for electronic delivery of tax forms



16
17
18
19
20
21
# File 'lib/adyen/services/legalEntityManagement/tax_e_delivery_consent_api.rb', line 16

def check_status_of_consent_for_electronic_delivery_of_tax_forms(id, headers: {})
  endpoint = build_endpoint('/legalEntities/{id}/checkTaxElectronicDeliveryConsent', id)
  
  action = { method: 'post', url: endpoint }
  @client.call_adyen_api(@service, action, {}, headers, @version)
end

Set the consent status for electronic delivery of tax forms



24
25
26
27
28
29
# File 'lib/adyen/services/legalEntityManagement/tax_e_delivery_consent_api.rb', line 24

def set_consent_status_for_electronic_delivery_of_tax_forms(request, id, headers: {})
  endpoint = build_endpoint('/legalEntities/{id}/setTaxElectronicDeliveryConsent', id)
  
  action = { method: 'post', url: endpoint }
  @client.call_adyen_api(@service, action, request, headers, @version)
end