Class: Adyen::DynamicOffersApi
- Defined in:
- lib/adyen/services/capital/dynamic_offers_api.rb
Overview
NOTE: This class is auto generated by OpenAPI Generator Ref: openapi-generator.tech
Do not edit the class manually.
Instance Attribute Summary collapse
-
#service ⇒ Object
Returns the value of attribute service.
-
#version ⇒ Object
Returns the value of attribute version.
Instance Method Summary collapse
-
#calculate_preliminary_offer_from_dynamic_offer(request, id, headers: {}) ⇒ Object
Calculate a preliminary offer for a selected financing amount.
-
#create_static_offer_from_dynamic_offer(request, id, headers: {}) ⇒ Object
Create a static offer for a selected financing amount.
-
#get_all_dynamic_offers(headers: {}, query_params: {}) ⇒ Object
Get all available dynamic offers.
-
#initialize(client, version = DEFAULT_VERSION) ⇒ DynamicOffersApi
constructor
A new instance of DynamicOffersApi.
Methods inherited from Service
action_for_method_name, #create_query_string
Constructor Details
#initialize(client, version = DEFAULT_VERSION) ⇒ DynamicOffersApi
Returns a new instance of DynamicOffersApi.
11 12 13 |
# File 'lib/adyen/services/capital/dynamic_offers_api.rb', line 11 def initialize(client, version = DEFAULT_VERSION) super(client, version, 'Capital') end |
Instance Attribute Details
#service ⇒ Object
Returns the value of attribute service.
9 10 11 |
# File 'lib/adyen/services/capital/dynamic_offers_api.rb', line 9 def service @service end |
#version ⇒ Object
Returns the value of attribute version.
9 10 11 |
# File 'lib/adyen/services/capital/dynamic_offers_api.rb', line 9 def version @version end |
Instance Method Details
#calculate_preliminary_offer_from_dynamic_offer(request, id, headers: {}) ⇒ Object
Calculate a preliminary offer for a selected financing amount
16 17 18 19 20 21 |
# File 'lib/adyen/services/capital/dynamic_offers_api.rb', line 16 def calculate_preliminary_offer_from_dynamic_offer(request, id, headers: {}) endpoint = build_endpoint('/dynamicOffers/{id}/calculate', id) action = { method: 'post', url: endpoint } @client.call_adyen_api(@service, action, request, headers, @version) end |
#create_static_offer_from_dynamic_offer(request, id, headers: {}) ⇒ Object
Create a static offer for a selected financing amount
24 25 26 27 28 29 |
# File 'lib/adyen/services/capital/dynamic_offers_api.rb', line 24 def create_static_offer_from_dynamic_offer(request, id, headers: {}) endpoint = build_endpoint('/dynamicOffers/{id}/grantOffer', id) action = { method: 'post', url: endpoint } @client.call_adyen_api(@service, action, request, headers, @version) end |
#get_all_dynamic_offers(headers: {}, query_params: {}) ⇒ Object
Get all available dynamic offers
32 33 34 35 36 37 |
# File 'lib/adyen/services/capital/dynamic_offers_api.rb', line 32 def get_all_dynamic_offers(headers: {}, query_params: {}) endpoint = build_endpoint('/dynamicOffers') endpoint += create_query_string(query_params) action = { method: 'get', url: endpoint } @client.call_adyen_api(@service, action, {}, headers, @version) end |